<?php

if (!interface_exists('IFind'))
	throw new Exception('IViewer: FileViewer: no interface found.');

class MFind implements IFind {
	private $glade;
	private $window;
	private $fsModule;
	private $button;
	private $where;
	private $what;
	private $result;
	private $status;
	private $trans;
	private $searching;
	
	public function __construct($mainwnd, $fsModule, $path, $whatToFind, $trans) {
		$searching = false;
		$this->glade = new GladeXML('./forms/find.glade');
		$this->window = $this->glade->get_widget('wndFind');
		$this->fsModule = $fsModule;
		$this->trans = $trans;
		$this->button = $this->glade->get_widget('buttonSearch');
		$this->where = $this->glade->get_widget('entryWhere');
		$this->what = $this->glade->get_widget('entryWhat');
		$this->result = $this->glade->get_widget('textviewResult');
		$this->status = $this->glade->get_widget('labelStatus');

		$this->button->connect_simple('clicked', 'object_callback', $this, 'find');
		$this->window->connect_simple('destroy', 'object_callback', $this, 'destroyHnd');
		$this->what->set_text($whatToFind);
		$this->what->connect('key_press_event', Array($this,'callBackKeypressed'), $this);
		$this->where->set_text($path);
		$this->where->connect('key_press_event', Array($this,'callBackKeypressed'), $this);

		$this->window->set_destroy_with_parent(true);
	}
	
	public function show() {
		$this->glade->get_widget('wndFind')->set_title($this->trans->translate('MFind_title'));
		$this->glade->get_widget('labelWhat')->set_text($this->trans->translate('MFind_label_what'));
		$this->glade->get_widget('labelWhere')->set_text($this->trans->translate('MFind_label_where'));
		$this->button->set_label($this->trans->translate('MFind_button_search'));
		$this->status->set_text($this->trans->translate('MFind_label_status_idle'));

		$this->window->show_all();
		$this->what->child_focus(Gtk::DIR_TAB_FORWARD);
	}
	
	public function destroyHnd() {
		$this->searching = false;
	}

	public function destroy() {
		$this->destroyHnd();
		$this->window->destroy();
	}

	public function find() {
		$this->searching = true;
		$this->status->set_text($this->trans->translate('MFind_label_status_searching'));
		$data = $this->findInPath($this->where->get_text(), $this->what->get_text());
		
		if ($this->searching) {
			if (count($data) == 0)
				$data = $this->trans->translate('MFind_nothing');
			else
				$data = implode("\n", $data);

			$buffer = $this->result->get_buffer();
			$buffer->set_text(iconv('ISO-8859-2', 'UTF-8', $data));
			$this->status->set_text($this->trans->translate('MFind_label_status_idle'));
			$this->searching = false;
		}
	}

	private function findInPath($path, $what) {
		$result = Array();
		if ($what == '')
			return $result;

		$this->status->set_text($this->trans->translate('MFind_label_status_searching_in').' '.iconv('ISO-8859-2', 'UTF-8', $path).'...');
		while (Gtk::events_pending()) Gtk::main_iteration();

		$separator = $this->fsModule->getSeparator();
		
		$dirs = $this->fsModule->getDirs($path);
		foreach($dirs as $dir) {
			if (!$this->searching) break;
			if (strpos($dir, $what) !== false)
				array_push($result, '['.$path.$dir.$separator.']');
			$result = array_merge($result, $this->findInPath($path.$dir.$separator, $what));
		}

		$files = $this->fsModule->getFiles($path);
		foreach($files as $file) {
			if (!$this->searching) break;
			if (strpos($file, $what) !== false)
				array_push($result, $path.$file);
		}

		return $result;
	}

	public static function callBackKeypressed($widget, $event, $module) {
		if ($event->keyval == Gdk::KEY_Return)
			$module->find();
	}
}

?>