<?php

if (!interface_exists('ITranslation'))
	throw new Exception('ITranslation: Translations: no interface found.');

class Translation implements ITranslation {
	
	private $currentLanguage;
	private $languageFile;
	private $words;
	private $files;
	private $env;
	
	
	public function __construct($language, &$env){
		$this->env = &$env;
		if($this->languageExists($language)){
			$this->currentLanguage = $language;
		} else {
			throw new Exception("Language file $language.xml not found\n");
		}
	}
	
	public function getLanguage(){
		return $this->currentLanguage;
	}
	
	public function getLanguages(){
		$this->files = array();
		$handle=opendir('./languages');
		$i = 0;
		while (($file = readdir($handle))!==false) {
			if('.xml' == substr($file, -4, 4)){
				$language = substr($file, 0, strlen($file)-4);
				if($this->languageExists($language)){
					$this->files[$i] = $language;
					$i++;
				}
			}
		}
		closedir($handle);
		return $this->files;
	}
	
	public function setLanguage($language){
		if($this->languageExists($language)){
			$this->currentLanguage = $language;
			$this->translateToArray();
			return true;
		} else {
			return false;
		}
	}
	
	public function translate($wordId){
		$ret = $this->words[$wordId];
		if($ret != ''){
			return $ret;
		} else {
			return '???';
		}
	}
	
	private function languageExists($language){
		$fileName = './languages/' . $language . '.xml';
	
		if(!file_exists($fileName)){
			$dialog = new GtkMessageDialog(
					$this->env['gui']['window'],
					0,
					Gtk::MESSAGE_QUESTION,
					Gtk::BUTTONS_OK,
					"File $language.xml not exists");
			
			$dialog->show();
			$result = $dialod->run();
					
			if($result == Gtk::RESPONSE_OK){
				$dialog->destroy();
			}
			
		} else {
		
			$doc = new DOMDocument();
			$doc->Load($fileName);
			$languageName = $doc->getElementsByTagName('name');
		
			
			if($languageName->item(0)->nodeValue == $language){
				$this->languageFile = $doc;
				return true; 
			} else { 
				$dialog = new GtkMessageDialog(
						$this->env['gui']['window'],
						0,
							Gtk::MESSAGE_QUESTION,
						Gtk::BUTTONS_OK,
						"File $language.xml exists but contains this language: " . $languageName->item(0)->nodeValue);
				
				$dialog->show();
				$result = $dialog->run();
				if($result == Gtk::RESPONSE_OK){
					$dialog->destroy();
				}
				
				return false;
			}
		}
	}
	
	private function translateToArray(){
		$this->words = array();
		
		$words = $this->languageFile->getElementsByTagName('translation');
		foreach ($words as $word) {
			$name = $word->nodeValue;
			$attribute = $word->getAttribute('id');
			$this->words[$attribute] = $name;
		}
	}
}

?>